@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 ##
 module MIME
 end
@@ -55,7 +57,7 @@ class MIME::Type
   end
 
   # The released version of the mime-types library.
-  VERSION = '3.1'
+  VERSION = '3.2.2'
 
   include Comparable
 
@@ -129,7 +131,11 @@ class MIME::Type
     elsif other.respond_to?(:simplified)
       simplified <=> other.simplified
     else
-      simplified <=> MIME::Type.simplified(other.to_s)
+      filtered = 'silent' if other == :silent
+      filtered ||= 'true' if other == true
+      filtered ||= other.to_s
+
+      simplified <=> MIME::Type.simplified(filtered)
     end
   end
 
@@ -151,7 +157,7 @@ class MIME::Type
   # before unregistered or obsolete content types.
   def priority_compare(other)
     pc = simplified <=> other.simplified
-    if pc.zero?
+    if pc.zero? || !(extensions & other.extensions).empty?
       pc = if (reg = registered?) != other.registered?
              reg ? -1 : 1 # registered < unregistered
            elsif (comp = complete?) != other.complete?
@@ -362,13 +368,7 @@ class MIME::Type
 
   ##
   def xrefs=(x) # :nodoc:
-    MIME::Types::Container.new.merge(x).tap do |xr|
-      xr.each do |k, v|
-        xr[k] = Set[*v] unless v.kind_of? Set
-      end
-
-      @xrefs = xr
-    end
+    @xrefs = MIME::Types::Container.new(x)
   end
 
   # The decoded cross-reference URL list for this MIME::Type.
@@ -453,7 +453,7 @@ class MIME::Type
     unless xrefs.empty?
       {}.tap do |hash|
         xrefs.each do |k, v|
-          hash[k] = v.sort.to_a
+          hash[k] = v.to_a.sort
         end
         coder['xrefs'] = hash
       end
