@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # -*- ruby encoding: utf-8 -*-
 
 require 'mime/types'
@@ -83,6 +85,12 @@ describe MIME::Types do
       refute_empty mime_types[/gzip/, registered: true]
       refute_equal mime_types[/gzip/], mime_types[/gzip/, registered: true]
     end
+
+    it 'properly returns an empty result on a regular expression miss' do
+      assert_empty mime_types[/^foo/]
+      assert_empty mime_types[/^foo/, registered: true]
+      assert_empty mime_types[/^foo/, complete: true]
+    end
   end
 
   describe '#add' do
@@ -143,7 +151,9 @@ describe MIME::Types do
     end
 
     it 'does not find unknown extensions' do
+      keys = mime_types.instance_variable_get(:@extension_index).keys
       assert_empty mime_types.type_for('zzz')
+      assert_equal keys, mime_types.instance_variable_get(:@extension_index).keys
     end
 
     it 'modifying type extensions causes reindexing' do
